from_solution_addrs

Function from_solution_addrs 

pub fn from_solution_addrs(
    solution_addrs: impl IntoIterator<Item = ContentAddress>,
) -> ContentAddress
Given the content address for each Solution in the SolutionSet, produce the solution set’s content address.

This collects all yielded content addresses into a Vec, sorts them and then hashes the result to produce the solution address.

If you have already collected the content address for each Solution into a slice, consider from_solution_addrs_slice.