from_solution_addrs_slice

Function from_solution_addrs_slice 

pub fn from_solution_addrs_slice(
    solution_addrs: &mut [ContentAddress],
) -> ContentAddress
Given the content address for each Solution in the SolutionSet, produce the solution’s content address.

This first sorts solution_addrs before producing the content address of the slice, ensuring that the address maintains “set” semantics (i.e. the order of its inner Solutions does not matter).