pub fn from_contract(contract: &Contract) -> ContentAddressExpand description
Shorthand for the common case of producing an contract address from an
iterator yielding references to Predicates.
If you have already calculated the content address for each predicate consider
using from_predicate_addrs or from_predicate_addrs_slice.